﻿$packageName = 'iTunes'
$version = '12.4'
$url = 'https://secure-appldnld.apple.com/itunes12/031-62803-20160516-DC22180C-1959-11E6-A359-D4135529DBDF/iTunesSetup.exe'
$url64bit = 'https://secure-appldnld.apple.com/itunes12/031-62806-20160516-DC2224E6-1959-11E6-BC22-D2135529DBDF/iTunes6464Setup.exe'
$fileType = 'msi'
$silentArgs = '/qn /norestart'
$validExitCodes = @(0, 3010)

$toolsDir = Split-Path -Parent $MyInvocation.MyCommand.Definition
$downloadTempDir = Join-Path $toolsDir 'download-temp'

$app = Get-WmiObject -Class Win32_Product | Where-Object {$_.Name -match 'iTunes'}

# Check if the same version of iTunes is already installed
if ($app -and ([version]$app.Version -ge [version]$version)) {
  Write-Output $(
    'iTunes ' + $version + ' or higher is already installed. ' +
    'No need to download and install again.'
  )
} else {

  Install-ChocolateyZipPackage -packageName $packageName -url $url `
    -url64bit $url64bit -unzipLocation $downloadTempDir

  $msiFilesList = (Get-ChildItem -Path $downloadTempDir -Filter '*.msi' | Where-Object {
    $_.Name -notmatch 'AppleSoftwareUpdate*.msi'
  }).Name

  # Loop over each file and install it. iTunes requires all of them to be installed
  foreach ($msiFileName in $msiFilesList) {
    Install-ChocolateyInstallPackage -packageName $msiFileName -fileType $fileType `
      -silentArgs $silentArgs -file (Join-Path $downloadTempDir $msiFileName) `
      -validExitCodes $validExitCodes
  }

  Remove-Item $downloadTempDir -Recurse
}
